@@ -1,4 +1,4 @@
-utils::globalVariables(c("k","v"))
+utils::globalVariables(c("k","v","n","dta","tvals"))
 #' cfa: A package for computing counterfactuals with a continuous treatment
 #'
 #' @docType package
@@ -9,5 +9,6 @@ utils::globalVariables(c("k","v"))
 #' @import BMisc
 #' @import quantreg
 #' @import TempleMetrics
-#' @import formula.tools
+#' @import pbapply
+#' @importFrom formula.tools lhs
 NULL
